@@ -40,7 +40,7 @@ import msgparsing
 from diff import seddiff
 
 
-VERSION = '1.35'
+VERSION = '1.36'
 
 
 class IrcDisconnectError(Exception): ...
@@ -81,7 +81,7 @@ class Provider(Enum):
 
 
 #: Inactivity days to hide a MPIM
-MPIM_HIDE_DELAY = datetime.timedelta(days=50)
+MPIM_HIDE_DELAY = datetime.timedelta(days=10)
 
 
 class ClientSettings(NamedTuple):
@@ -263,7 +263,11 @@ class Client:
                     # Disabled user, skip it
                     continue
                 name = u.name.encode('utf8')
-                prefix = b'@' if u.is_admin else b''
+                prefix = b''
+                if u.is_admin:
+                    prefix = b'@'
+                elif u.is_bot:
+                    prefix = b'+'
                 userlist.append(prefix + name)
 
             users = b' '.join(userlist)
@@ -562,7 +566,9 @@ class Client:
         if user.profile.email:
             await self._sendreply(Replies.RPL_WHOISUSER, f'email: {user.profile.email}', [username, '', 'localhost'])
         if user.is_admin:
-            await self._sendreply(Replies.RPL_WHOISOPERATOR, f'{uusername} is an IRC operator', [username])
+            await self._sendreply(Replies.RPL_WHOISOPERATOR, f'{uusername} is an admin', [username])
+        if user.is_bot:
+            await self._sendreply(Replies.RPL_WHOISUSER, f'{uusername} is a bot', [username])
         if await self.sl_client.isAway(user):
             await self._sendreply(Replies.RPL_AWAY, f'{uusername} is away', extratokens=[username])
         await self._sendreply(Replies.RPL_ENDOFWHOIS, '', extratokens=[username])
@@ -646,12 +652,6 @@ class Client:
         except KeyError:
             return
 
-        for i in await self.sl_client.get_members(channel.id):
-            try:
-                user = await self.sl_client.get_user(i)
-                await self._sendreply(Replies.RPL_WHOREPLY, '0 %s' % user.real_name, [name, user.name, '127.0.0.1', self.hostname, user.name, 'H'])
-            except Exception:
-                pass
         await self._sendreply(Replies.RPL_ENDOFWHO, 'End of WHO list', [name])
 
     async def sendmsg(self, from_: bytes, to: bytes, message: bytes) -> None:
@@ -821,7 +821,7 @@ class Client:
             dest = self.nick
             yelldest = b''
         except Exception as e:
-            log('Error: ', str(e))
+            error('Error: ', str(e))
             return
 
         text = sl_ev.text
@@ -924,6 +924,12 @@ class Client:
         elif isinstance(sl_ev, slack.GroupJoined) or isinstance(sl_ev, slack.MpimJoined):
             channel_name = '#%s' % sl_ev.channel.name_normalized
             await self._send_chan_info(channel_name.encode('utf-8'), sl_ev.channel)
+        elif isinstance(sl_ev, slack.PresenceChange):
+            user = await self.sl_client.get_user(sl_ev.user)
+            if sl_ev.away():
+                await self._sendreply(Replies.RPL_AWAY, f'{user.name} is away', extratokens=[user.name])
+            else:
+                await self._sendreply(Replies.RPL_UNAWAY, f'{user.name} is not away', extratokens=[user.name])
 
     async def command(self, cmd: bytes) -> None:
         if b' ' in cmd:
@@ -966,7 +972,7 @@ class Client:
             await handlers[cmdid](cmd)
         else:
             await self._sendreply(Replies.ERR_UNKNOWNCOMMAND, 'Unknown command', [cmdid])
-            log('Unknown command: ', cmd)
+            warning('Unknown command: ', cmd)
 
 
 def su() -> None:
@@ -1229,7 +1235,7 @@ async def to_irc(sl_client: slack.Slack, ircclient: Client):
     while True:
         ev = await sl_client.event()
         if ev:
-            log(ev)
+            debug(ev)
             await ircclient.slack_event(ev)
 
 
