@@ -1,5 +1,5 @@
 # localslackirc
-# Copyright (C) 2022 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2022-2025 Salvo "LtWorf" Tomaselli
 #
 # localslackirc is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 from enum import Enum
-from typing import Iterable, NamedTuple, Optional
+from typing import Iterable, NamedTuple
 
 try:
     from emoji import emojize, demojize # type: ignore
@@ -127,7 +127,7 @@ class SpecialItem(NamedTuple):
         return self.txt[1:sep]
 
     @property
-    def human(self) -> Optional[str]:
+    def human(self) -> str | None:
         """
         Return the eventual human readable
         message
@@ -154,7 +154,13 @@ def split_tokens(msg: str) -> Iterable[SpecialItem|str]:
             yield msg[0:begin]
             msg = msg[begin:]
         else: # Tag at the beginning
-            end = msg.index('>')
+            try:
+                # Sometimes the fuckers at slack do not escape
+                # the < string, so if we can't find the matching closing
+                # let's return it as a string and hope for the best
+                end = msg.index('>')
+            except ValueError:
+                break
             block = msg[0:end + 1]
             msg = msg[end + 1:]
             yield SpecialItem(block)
