@@ -27,7 +27,7 @@ from typedload import dataloader
 
 from slackclient import SlackClient
 from slackclient.client import LoginInfo
-from log import log, debug
+from log import *
 
 
 T = TypeVar('T')
@@ -49,6 +49,7 @@ USELESS_EVENTS = frozenset((
     'hello',
     'dnd_updated_user',
     'reaction_added',
+    'reaction_removed',
     'file_deleted',
     'file_public',
     'file_created',
@@ -275,6 +276,7 @@ class User(NamedTuple):
     name: str
     profile: Profile
     is_admin: bool = False
+    is_bot: bool = False
     deleted: bool = False
 
     @property
@@ -308,6 +310,10 @@ class TopicChange:
     channel: str
     user: str
 
+@dataclass
+class PresenceChange(Presence):
+    type: Literal['presence_change']
+    user: str
 
 @dataclass
 class HistoryBotMessage:
@@ -359,7 +365,8 @@ SlackEvent = (
     Leave|
     GroupJoined|
     MpimJoined|
-    UserTyping
+    UserTyping|
+    PresenceChange
 )
 
 
@@ -407,6 +414,7 @@ class Slack:
         self.client = SlackClient(token, cookie)
         self._usercache: dict[str, User] = {}
         self._usermapcache: dict[str, User] = {}
+        self._user_away: dict[str, bool] = {}
         self._imcache: dict[str, str] = {}
         self._channelscache: list[Channel] = []
         self._joinedchannelscache: list[Channel] = []
@@ -463,7 +471,7 @@ class Slack:
             try:
                 response = self.tload(p, History)
             except Exception as e:
-                    log('Failed to parse', e)
+                    error('Failed to parse', e)
                     log(p)
                     break
             r += [i for i in response.messages if i.ts != i.thread_ts]
@@ -475,13 +483,30 @@ class Slack:
         r[0].thread_ts = None
         return r
 
+    async def _users_in_my_channels(self) -> set[str]:
+        r: set[str] = set()
+
+        chats: Sequence[IM|Channel] = await self.channels() + await self.get_ims()  # type: ignore
+        for channel in chats:
+            if isinstance(channel, Channel):
+                if not channel.is_member:
+                    continue
+                # Get members of this channel
+                r.union(await self.get_members(channel))
+            else:
+                if channel.is_user_deleted:
+                    continue
+                else:
+                    r.add(channel.user)
+        return r
+
     async def _history(self) -> None:
         '''
         Obtain the history from the last known event and
         inject fake events as if the messages are coming now.
         '''
         if self._status.last_timestamp == 0:
-            log('No last known timestamp. Unable to fetch history')
+            warning('No last known timestamp. Unable to fetch history')
             return
 
         log('Fetching history...')
@@ -489,7 +514,7 @@ class Slack:
         last_timestamp = self._status.last_timestamp
         FOUR_DAYS = 60 * 60 * 24 * 4
         if time() - last_timestamp > FOUR_DAYS:
-            log('Last timestamp is too old. Defaulting to 4 days.')
+            warning('Last timestamp is too old. Defaulting to 4 days.')
             last_timestamp = time() - FOUR_DAYS
         try:
             dt = datetime.datetime.fromtimestamp(last_timestamp)
@@ -511,11 +536,11 @@ class Slack:
 
             cursor = None
             while True: # Loop to iterate the cursor
-                log('Calling cursor')
+                debug('Calling cursor')
                 try:
                     response = await self.get_history(channel, str(last_timestamp))
                 except Exception as e:
-                    log('Failed to parse', e)
+                    error('Failed to parse', e)
                     break
                 msg_list = list(response.messages)
                 while msg_list:
@@ -685,11 +710,18 @@ class Slack:
             raise ResponseException(response.error)
 
     async def isAway(self, user: User) -> bool:
+        try:
+            return self._user_away[user.id]
+        except KeyError:
+            pass
+
         r = await self.client.api_call('users.getPresence', user=user.id)
         response = self.tload(r, Response)
         if not response.ok:
             raise ResponseException(response.error)
-        return self.tload(r, Presence).away()
+        away = self.tload(r, Presence).away()
+        self._user_away[user.id] = away
+        return away
 
     async def join(self, channel: Channel) -> None:
         r = await self.client.api_call('conversations.join', channel=channel.id)
@@ -1037,7 +1069,9 @@ class Slack:
         This returns the events from the slack websocket
         """
         if self._internalevents:
-            return self._internalevents.pop()
+            ie = self._internalevents.pop()
+            debug(ie)
+            return ie
 
         try:
             events = await self.client.rtm_read()
@@ -1045,6 +1079,8 @@ class Slack:
             log('Connecting to slack...')
             self.login_info = await self.client.rtm_connect(5)
             await self._history()
+
+            await self.client.monitor_presence(await self._users_in_my_channels())
             log('Connected to slack')
             return None
 
@@ -1062,7 +1098,7 @@ class Slack:
                 continue
 
             debug(event)
-            loadable_events = TopicChange|MessageBot|MessageEdit|MessageDelete|GroupJoined|Join|Leave|UserTyping|MpimJoined
+            loadable_events = PresenceChange|TopicChange|MessageBot|MessageEdit|MessageDelete|GroupJoined|Join|Leave|UserTyping|MpimJoined
             try:
                 ev: loadable_events | None = self.tload(
                     event,
@@ -1079,6 +1115,8 @@ class Slack:
             elif isinstance(ev, UserTyping):
                 await self._annoy(ev)
                 continue
+            elif isinstance(ev, PresenceChange):
+                self._user_away[ev.user] = ev.away()
 
             if ev:
                 return ev
@@ -1116,8 +1154,8 @@ class Slack:
                         #FIXME don't know if it is wise, maybe it gets lost forever del self._usermapcache[u.name]
                     #TODO make an event for this
                 else:
-                    log(event)
+                    debug(event)
             except Exception as e:
-                log('Exception: %s' % e)
+                error('Exception: %s' % e)
             self._triage_sent_by_self()
         return None
