@@ -23,7 +23,7 @@
 
 import asyncio
 import json
-from typing import Any, NamedTuple, Optional
+from typing import Any, NamedTuple, Iterable
 
 from typedload import load
 from websockets.asyncio.client import connect as wsconnect, ClientConnection
@@ -54,13 +54,13 @@ class SlackClient:
     The SlackClient object owns the websocket connection and all attached channel information.
     """
 
-    def __init__(self, token: str, cookie: Optional[str]) -> None:
+    def __init__(self, token: str, cookie: str | None) -> None:
         # Slack client configs
         self._token = token
         self._cookie = cookie
 
         # RTM configs
-        self._websocket: Optional[ClientConnection] = None
+        self._websocket: ClientConnection | None = None
         self._request = Request('https://slack.com/api/')
         self._wsid = 0
 
@@ -176,3 +176,13 @@ class SlackClient:
             for d in json_data.split('\n'):
                 data.append(json.loads(d))
         return data
+
+    async def monitor_presence(self, users: Iterable[str]) -> None:
+        """
+        Tells slack to send events when the presence status of the users changes
+        """
+        assert self._websocket
+        await self._websocket.send(json.dumps({
+            "type": "presence_sub",
+            "ids": list(users)
+        }))
