@@ -96,7 +96,10 @@ class Request:
 
     def __del__(self):
         for i in self._connections.values():
-            i[1].close()
+            try:
+                i[1].close()
+            except Exception:
+                pass # best effort
 
     async def _connect(self) -> tuple[asyncio.streams.StreamReader, asyncio.streams.StreamWriter]:
         """
